# pylacoan

 Plug-and-play language corpus annotation.

![License](https://img.shields.io/github/license/fmatter/pylacoan)
[![Documentation Status](https://readthedocs.org/projects/pylacoan/badge/?version=latest)](https://pylacoan.readthedocs.io/en/latest/?badge=latest)
[![Tests](https://img.shields.io/github/actions/workflow/status/fmatter/pylacoan/tests.yml?label=tests)](https://github.com/fmatter/pylacoan/actions/workflows/tests.yml)
[![Linting](https://img.shields.io/github/actions/workflow/status/fmatter/pylacoan/lint.yml?label=linting)](https://github.com/fmatter/pylacoan/actions/workflows/lint.yml)
[![Codecov](https://img.shields.io/codecov/c/github/fmatter/pylacoan)](https://app.codecov.io/gh/fmatter/pylacoan/)
[![PyPI](https://img.shields.io/pypi/v/pylacoan.svg)](https://pypi.org/project/pylacoan)
![Versions](https://img.shields.io/pypi/pyversions/pylacoan)

* [Read the docs](https://pylacoan.readthedocs.io)